# visualizer

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Veekay IT (c) 2023

## Examples of How To Use (Buggy Alpha Version)

Use with Elmo Visualizer Products, Connect the visualizer to Ubuntu System through USB cable.
open the application after proper installation from ubuntu terminal.
click the change cam button to use the visualizer cam view. 